@@ -74,32 +74,35 @@ class Aperture(_BaseWithShade):
         Args:
             data: A dictionary representation of an Aperture object.
         """
-        # check the type of dictionary
-        assert data['type'] == 'Aperture', 'Expected Aperture dictionary. ' \
-            'Got {}.'.format(data['type'])
+        try:
+            # check the type of dictionary
+            assert data['type'] == 'Aperture', 'Expected Aperture dictionary. ' \
+                'Got {}.'.format(data['type'])
 
-        # serialize the aperture
-        is_operable = data['is_operable'] if 'is_operable' in data else False
-        if data['boundary_condition']['type'] == 'Outdoors':
-            boundary_condition = Outdoors.from_dict(data['boundary_condition'])
-        elif data['boundary_condition']['type'] == 'Surface':
-            boundary_condition = Surface.from_dict(data['boundary_condition'], True)
-        else:
-            raise ValueError(
-                'Boundary condition "{}" is not supported for Apertures.'.format(
-                    data['boundary_condition']['type']))
-        aperture = cls(data['identifier'], Face3D.from_dict(data['geometry']),
-                       boundary_condition, is_operable)
-        if 'display_name' in data and data['display_name'] is not None:
-            aperture.display_name = data['display_name']
-        if 'user_data' in data and data['user_data'] is not None:
-            aperture.user_data = data['user_data']
-        aperture._recover_shades_from_dict(data)
+            # serialize the aperture
+            is_operable = data['is_operable'] if 'is_operable' in data else False
+            if data['boundary_condition']['type'] == 'Outdoors':
+                boundary_condition = Outdoors.from_dict(data['boundary_condition'])
+            elif data['boundary_condition']['type'] == 'Surface':
+                boundary_condition = Surface.from_dict(data['boundary_condition'], True)
+            else:
+                raise ValueError(
+                    'Boundary condition "{}" is not supported for Apertures.'.format(
+                        data['boundary_condition']['type']))
+            aperture = cls(data['identifier'], Face3D.from_dict(data['geometry']),
+                           boundary_condition, is_operable)
+            if 'display_name' in data and data['display_name'] is not None:
+                aperture.display_name = data['display_name']
+            if 'user_data' in data and data['user_data'] is not None:
+                aperture.user_data = data['user_data']
+            aperture._recover_shades_from_dict(data)
 
-        # assign extension properties
-        if data['properties']['type'] == 'ApertureProperties':
-            aperture.properties._load_extension_attr_from_dict(data['properties'])
-        return aperture
+            # assign extension properties
+            if data['properties']['type'] == 'ApertureProperties':
+                aperture.properties._load_extension_attr_from_dict(data['properties'])
+            return aperture
+        except Exception as e:
+            cls._from_dict_error_message(data, e)
 
     @classmethod
     def from_vertices(cls, identifier, vertices, boundary_condition=None,
